summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/nautilus-window.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nautilus-window.c b/src/nautilus-window.c
index 0033dcf5d..fabd70b0b 100644
--- a/src/nautilus-window.c
+++ b/src/nautilus-window.c
@@ -1184,15 +1184,15 @@ toast_undo_deleted_get_label (NautilusFileUndoInfo *undo_info)
if (length == 1)
{
file_label = g_file_get_basename (files->data);
/* Translators: only one item has been deleted and %s is its name. */
label = g_markup_printf_escaped (_("ā€œ%sā€ moved to trash"), file_label);
g_free (file_label);
}
else
{
/* Translators: one or more items might have been deleted, and %d
* is the count. */
- label = g_markup_printf_escaped (ngettext ("%d file deleted", "%d files deleted", length), length);
+ label = g_markup_printf_escaped (ngettext ("%d file moved to trash", "%d files moved to trash", length), length);
}
return label;
@@ -1184,15 +1184,15 @@ toast_undo_deleted_get_label (NautilusFileUndoInfo *undo_info)
{
file_label = g_file_get_basename (files->data);
- /* Translators: only one item has been deleted and %s is its name. */
+ /* Translators: only one item has been moved to trash and %s is its name. */
label = g_markup_printf_escaped (_("ā€œ%sā€ moved to trash"), file_label);
g_free (file_label);
@@ -1184,15 +1184,15 @@ toast_undo_deleted_get_label (NautilusFileUndoInfo *undo_info)
else
{
- /* Translators: one or more items might have been deleted, and %d
+ /* Translators: one or more items might have been moved to trash, and %d
* is the count. */